@@ -3,7 +3,6 @@
    details, or visit https://github.com/ocsigen/lwt/blob/master/LICENSE.md. *)
 
 
-
 (** Cooperative system calls *)
 
 (** This modules maps system calls, like those of the standard
@@ -212,8 +211,16 @@ val fork : unit -> int
       - None of the above is necessary if you intend to call [exec]. Indeed, in
         that case, it is not even necessary to use [Lwt_unix.fork]. You can use
         {!Unix.fork}.
-      - To abandon some more promises, see
-        {!Lwt_main.abandon_yielded_and_paused}. *)
+      - To abandon some more promises, see {!Lwt.abandon_paused}.
+
+      Furthermore:
+
+      - Calling [Lwt_unix.fork] raises an execption if [Domain.spawn] has been
+        called at any point in the program's past.
+      - Calling [Lwt_unix.fork] can result in the child process being in a
+        corrupted state if any thread has been started. Lwt starts threads when
+        [Lwt_preemptive.detach] is called. Lwt implicitly starts threads to
+        perform blocking I/O unless the {!async_method} is set to [Async_none]. *)
 
 type process_status =
     Unix.process_status =
@@ -258,7 +265,10 @@ val system : string -> process_status Lwt.t
   (** Executes the given command, waits until it terminates, and
       return its termination status. The string is interpreted by the
       shell [/bin/sh] on Unix and [cmd.exe] on Windows. The result
-      [WEXITED 127] indicates that the shell couldn't be executed. *)
+      [WEXITED 127] indicates that the shell couldn't be executed.
+
+      The function uses {!fork} internally. As a result, this function is
+      brittle. See all the warnings relating to [fork] for more details. *)
 
 (** {2 Basic file input/output} *)
 
@@ -436,7 +446,7 @@ val readv : file_descr -> IO_vectors.t -> int Lwt.t
     Not implemented on Windows. It should be possible to implement, upon
     request, for Windows sockets only.
 
-    See {{:http://man7.org/linux/man-pages/man3/readv.3p.html} [readv(3p)]}.
+    See {{:https://man7.org/linux/man-pages/man3/readv.3p.html} [readv(3p)]}.
 
     @since 2.7.0 *)
 
@@ -465,7 +475,7 @@ val writev : file_descr -> IO_vectors.t -> int Lwt.t
     and write zero bytes. On BSD (including macOS), [writev] will fail with
     [Unix.Unix_error (Unix.EINVAL, "writev", ...)].
 
-    See {{:http://man7.org/linux/man-pages/man3/writev.3p.html}
+    See {{:https://man7.org/linux/man-pages/man3/writev.3p.html}
     [writev(3p)]}.
 
     @since 2.7.0 *)
@@ -587,7 +597,7 @@ val utimes : string -> float -> float -> unit Lwt.t
     to [mtime]. To set both to the current time, call [utimes path 0. 0.].
 
     This function corresponds to {!Unix.utimes}. See also
-    {{:http://man7.org/linux/man-pages/man3/utimes.3p.html} [utimes(3p)]}.
+    {{:https://man7.org/linux/man-pages/man3/utimes.3p.html} [utimes(3p)]}.
 
     @since 2.6.0 *)
 
@@ -855,6 +865,14 @@ val reinstall_signal_handler : int -> unit
       signal handler (with [Sys.set_signal]). This is useful in case
       another part of the program install another signal handler. *)
 
+val handle_signal : int -> unit
+  (** [handle_signal signum] acts as if Lwt had received the [signum] signal.
+      This allows another IO library to install the handler, perform its own
+      handling, but still notify Lwt. It is particularly useful for SIGCHLD,
+      where several IO libraries may be spawning sub-processes.
+
+      This function is thread-safe. *)
+
 (** {2 Sockets} *)
 
 type inet_addr = Unix.inet_addr
@@ -886,7 +904,7 @@ val socketpair : ?cloexec:bool ->
 val bind : file_descr -> sockaddr -> unit Lwt.t
 (** Binds an address to the given socket. This is the cooperative analog of
     {!Unix.bind}. See also
-    {{:http://man7.org/linux/man-pages/man3/bind.3p.html} [bind(3p)]}.
+    {{:https://man7.org/linux/man-pages/man3/bind.3p.html} [bind(3p)]}.
 
     @since 3.0.0 *)
 
@@ -915,7 +933,7 @@ val accept_n : ?cloexec:bool ->
       [accept_n] has the advantage of improving performance. If you
       want a more detailed description, you can have a look at:
 
-      {{:http://portal.acm.org/citation.cfm?id=1247435}Acceptable strategies for improving web server performance} *)
+      {{:https://dl.acm.org/doi/10.5555/1247415.1247435}Acceptable strategies for improving web server performance} *)
 
 val connect : file_descr -> sockaddr -> unit Lwt.t
   (** Wrapper for {!Unix.connect} *)
@@ -1033,10 +1051,10 @@ type socket_bool_option =
   | TCP_NODELAY
   | IPV6_ONLY
   
-# 1035 "src/unix/lwt_unix.cppo.mli"
+# 1053 "src/unix/lwt_unix.cppo.mli"
   | SO_REUSEPORT
 
-# 1038 "src/unix/lwt_unix.cppo.mli"
+# 1056 "src/unix/lwt_unix.cppo.mli"
 type socket_int_option =
     Unix.socket_int_option =
   | SO_SNDBUF
@@ -1273,98 +1291,59 @@ val tcflow : file_descr -> flow_action -> unit Lwt.t
 
 
 
-(** {2 Configuration (deprecated)} *)
+(** {2 Configuration} *)
 
 (** For system calls that cannot be made asynchronously, Lwt uses one
     of the following method: *)
 type async_method =
   | Async_none
       (** System calls are made synchronously, and may block the
-          entire program. *)
+          entire program.
+
+          The main use cases for this are:
+          - debugging (execution is simpler)
+          - working with fork and exec (which are not thread-safe)
+          - when calling specific blocking I/O which is known to be fast *)
   | Async_detach
       (** System calls are made in another system thread, thus without
           blocking other Lwt promises. The drawback is that it may
           degrade performance in some cases.
 
           This is the default. *)
-  | Async_switch
-    [@ocaml.deprecated " Use Lwt_unix.Async_detach."]
-      (** @deprecated A synonym for [Async_detach]. This was a
-          different method in the past. *)
 
 val default_async_method : unit -> async_method
-  [@@ocaml.deprecated
-" Will always return Async_detach in Lwt >= 5.0.0. See
-   https://github.com/ocsigen/lwt/issues/572"]
 (** Returns the default async method.
 
     This can be initialized using the environment variable
-    ["LWT_ASYNC_METHOD"] with possible values ["none"],
-    ["detach"] and ["switch"].
-
-    @deprecated Will always return [Async_detach] in Lwt 5.0.0. *)
+    ["LWT_ASYNC_METHOD"] with possible values ["none"] and
+    ["detach"].
+*)
 
 val set_default_async_method : async_method -> unit
-  [@@ocaml.deprecated
-" Will be a no-op in Lwt >= 5.0.0. See
-   https://github.com/ocsigen/lwt/issues/572"]
-(** Sets the default async method.
-
-    @deprecated Will be a no-op in Lwt 5.0.0. *)
+(** Sets the default async method. *)
 
 val async_method : unit -> async_method
-  [@@ocaml.deprecated
-" Will always return Async_detach in Lwt >= 5.0.0. See
-   https://github.com/ocsigen/lwt/issues/572"]
 (** [async_method ()] returns the async method used in the current
-    thread.
-
-    @deprecated Will always return [Async_detach] in Lwt 5.0.0. *)
+    thread. *)
 
 val async_method_key : async_method Lwt.key
-  [@@ocaml.deprecated
-" Will be ignored in Lwt >= 5.0.0. See
-   https://github.com/ocsigen/lwt/issues/572"]
-(** The key for storing the local async method.
-
-    @deprecated Will be ignored in Lwt 5.0.0. *)
+(** The key for storing the local async method. *)
 
 val with_async_none : (unit -> 'a) -> 'a
-  [@@ocaml.deprecated
-" Will have no effect in Lwt >= 5.0.0. See
-   https://github.com/ocsigen/lwt/issues/572"]
 (** [with_async_none f] is a shorthand for:
 
     {[
       Lwt.with_value async_method_key (Some Async_none) f
     ]}
-
-    @deprecated Will have no effect in Lwt 5.0.0. *)
+*)
 
 val with_async_detach : (unit -> 'a) -> 'a
-  [@@ocaml.deprecated
-" Will have no effect in Lwt >= 5.0.0. See
-   https://github.com/ocsigen/lwt/issues/572"]
 (** [with_async_detach f] is a shorthand for:
 
     {[
       Lwt.with_value async_method_key (Some Async_detach) f
     ]}
-
-    @deprecated Will have no effect in Lwt 5.0.0. *)
-
-val with_async_switch : (unit -> 'a) -> 'a
-  [@@ocaml.deprecated
-" Will have no effect in Lwt >= 5.0.0. See
-   https://github.com/ocsigen/lwt/issues/572"]
-(** [with_async_switch f] is a shorthand for:
-
-    {[
-      Lwt.with_value async_method_key (Some Async_switch) f
-    ]}
-
-    @deprecated Will have no effect in Lwt 5.0.0. *)
-
+*)
 
 
 (** {2 Low-level interaction} *)
@@ -1452,20 +1431,14 @@ val cancel_jobs : unit -> unit
 val wait_for_jobs : unit -> unit Lwt.t
   (** Wait for all pending jobs to terminate. *)
 
-val execute_job :
-  ?async_method : async_method ->
-  job : 'a job ->
-  result : ('a job -> 'b) ->
-  free : ('a job -> unit) -> 'b Lwt.t
-  [@@ocaml.deprecated " Use Lwt_unix.run_job."]
-  (** @deprecated Use [run_job]. *)
-
 (** {2 Notifications} *)
 
 (** Lwt internally use a pipe to send notification to the main
     thread. The following functions allow to use this pipe. *)
 
-val make_notification : ?once : bool -> (unit -> unit) -> int
+type notification
+
+val make_notification : ?once : bool -> (unit -> unit) -> notification
   (** [make_notification ?once f] registers a new notifier. It returns the
       id of the notifier. Each time a notification with this id is
       received, [f] is called.
@@ -1473,21 +1446,21 @@ val make_notification : ?once : bool -> (unit -> unit) -> int
       if [once] is specified, then the notification is stopped after
       the first time it is received. It defaults to [false]. *)
 
-val send_notification : int -> unit
+val send_notification : notification -> unit
   (** [send_notification id] sends a notification.
 
       This function is thread-safe. *)
 
-val stop_notification : int -> unit
+val stop_notification : notification -> unit
   (** Stop the given notification. Note that you should not reuse the
       id after the notification has been stopped, the result is
       unspecified if you do so. *)
 
-val call_notification : int -> unit
+val call_notification : notification -> unit
   (** Call the handler associated to the given notification. Note that
       if the notification was defined with [once = true] it is removed. *)
 
-val set_notification : int -> (unit -> unit) -> unit
+val set_notification : notification -> (unit -> unit) -> unit
   (** [set_notification id f] replace the function associated to the
       notification by [f]. It raises [Not_found] if the given
       notification is not found. *)
@@ -1573,10 +1546,6 @@ end
 
 (**/**)
 
-val run : 'a Lwt.t -> 'a
-  [@@ocaml.deprecated " Use Lwt_main.run."]
-  (** @deprecated Use [Lwt_main.run]. *)
-
 val has_wait4 : bool
   [@@ocaml.deprecated " Use Lwt_sys.have `wait4."]
   (** @deprecated Use [Lwt_sys.have `wait4]. *)
@@ -1585,9 +1554,6 @@ val somaxconn : unit -> int
   [@@ocaml.deprecated " This is an internal function."]
   (** @deprecated This is for internal use only. *)
 
-val retained : 'a -> bool ref
-  (** @deprecated Used for testing. *)
-
 val read_bigarray :
   string -> file_descr -> IO_vectors._bigarray -> int -> int -> int Lwt.t
   [@@ocaml.deprecated " This is an internal function."]
@@ -1597,3 +1563,6 @@ val write_bigarray :
   string -> file_descr -> IO_vectors._bigarray -> int -> int -> int Lwt.t
   [@@ocaml.deprecated " This is an internal function."]
   (** @deprecated This is for internal use only. *)
+
+val write_job_count_runtimte_event : unit -> unit
+val sigchld_handler_installer : unit Lazy.t
